probnum.kernels
========================

Kernels or covariance functions.

Kernels describes the spatial or temporal variation of a random process. If
evaluated at two sets of points a kernel is defined as the covariance of the
values of the random process at these locations.

.. automodapi:: probnum.kernels
    :no-heading:
    :no-main-docstr:
